
.. image:: media/MergeDB-color.png
    :scale: 50 %

MergeDB
=======

MergeDB is a YAML based hierarchical database with a customizable rule-based deep merge system.

It allows you to smash YAML files together with precision, enabling you to generate YAML for automation tools without
repeating yourself.
